Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(470)

Unified Diff: src/mips/code-stubs-mips.cc

Issue 2244673002: [regexp][liveedit] Fix inconsistent JSArrays (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/js/regexp.js ('k') | src/mips64/code-stubs-mips64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/mips/code-stubs-mips.cc
diff --git a/src/mips/code-stubs-mips.cc b/src/mips/code-stubs-mips.cc
index e1ea870aa6ced10b79d246edc673866d2a62e380..844958ec47474e2f9dfe8b4704911f8fb8112db2 100644
--- a/src/mips/code-stubs-mips.cc
+++ b/src/mips/code-stubs-mips.cc
@@ -1628,8 +1628,8 @@ void RegExpExecStub::Generate(MacroAssembler* masm) {
__ lw(a0, MemOperand(sp, kLastMatchInfoOffset));
__ JumpIfSmi(a0, &runtime);
__ GetObjectType(a0, a2, a2);
- __ Branch(&runtime, ne, a2, Operand(JS_ARRAY_TYPE));
- // Check that the JSArray is in fast case.
+ __ Branch(&runtime, ne, a2, Operand(JS_OBJECT_TYPE));
+ // Check that the object has fast elements.
__ lw(last_match_info_elements,
FieldMemOperand(a0, JSArray::kElementsOffset));
__ lw(a0, FieldMemOperand(last_match_info_elements, HeapObject::kMapOffset));
« no previous file with comments | « src/js/regexp.js ('k') | src/mips64/code-stubs-mips64.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698